@@ -29,14 +29,14 @@
 
 namespace xmlpp {
   
-class internal_error: public exception
+class LIBXMLPP_API internal_error: public exception
 {
 public:
   explicit internal_error(const Glib::ustring& message);
-  virtual ~internal_error() throw();
+  ~internal_error() noexcept override;
 
-  virtual void Raise() const;
-  virtual exception * Clone() const;
+  void Raise() const override;
+  exception * Clone() const override;
 };
 
 } // namespace xmlpp
