@@ -8,10 +8,6 @@
 #ifndef __LIBXMLPP_VALIDATOR_H
 #define __LIBXMLPP_VALIDATOR_H
 
-#ifdef _MSC_VER //Ignore warnings about the Visual C++ Bug, where we can not do anything
-#pragma warning (disable : 4786)
-#endif
-
 #include <libxml++/nodes/element.h>
 #include <libxml++/exceptions/validity_error.h>
 #include <libxml++/exceptions/internal_error.h>
@@ -24,7 +20,7 @@ namespace xmlpp {
 
 /** Base class for XML validators.
  */
-class Validator : NonCopyable
+class LIBXMLPP_API Validator : NonCopyable
 {
 public:
   Validator();
